Image

Struct Image 

pub struct Image { /* private fields */ }
Image represents a texture that can be drawn on the screen.

Images are immutable, in the sense that they have no methods to modify their contents.

Implementations

Source

impl Image

pub fn get_width(&self) -> u32

pub fn get_height(&self) -> u32