pub struct Font { /* private fields */ }Expand description
Font is a way to render text, loaded from a specially formatted image.
Note that Font is not loaded from a TrueType file, but instead, from a specially formatted image. Loading from an image is a little faster and a little simpler and a little more portable, but has a couple disadvantages. For one, the font size is fixed by the file. To have two different font sizes, you have to create two different Fonts from two different files. Another disadvantage is that these special images are less widely available.
This link describes how ImageFonts work: https://love2d.org/wiki/Tutorial:Fonts_and_Text
Implementations
Sourceimpl Font
impl Font
Sourcepub fn is_printable(&self, ch: char) -> bool
pub fn is_printable(&self, ch: char) -> bool
Determine whether “ch” exists in this Font.
Sourcepub fn get_height(&self) -> u32
pub fn get_height(&self) -> u32
Return the height of the Font. This is constant for every possible character, while the
individual character widths vary. Note that certain characters (such a single quote ')
might not actually take up all of height. However, no character may exceed this limit.