pub struct Image { /* private fields */ }Expand description
Image represents a texture that can be drawn on the screen.
Images are immutable, in the sense that they have no methods to modify their contents.
Implementations